"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DatePicker = DatePicker;

var _style = _interopRequireDefault(require("styled-jsx/style"));

var React = _interopRequireWildcard(require("react"));

var _times = _interopRequireDefault(require("lodash/times"));

var _Backdrop = require("./Backdrop");

var _Grid = require("./Grid");

var _Updating = require("./Updating");

var _LeftLineBlack = _interopRequireDefault(require("../static/images/icons/Left-Line-Black-24.svg"));

var _RightLineBlack = _interopRequireDefault(require("../static/images/icons/Right-Line-Black-24.svg"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; if (obj != null) { var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/* eslint-disable jsx-a11y/no-static-element-interactions, jsx-a11y/click-events-have-key-events */
var AVAILABILITY_STATUSES = {
  unknown: 'unknown',
  available: 'available',
  unavailable: 'unavailable'
};
var i18n = {
  nb: {
    days: ['Søn', 'Man', 'Tir', 'Ons', 'Tor', 'Fre', 'Lør', 'Søndag', 'Mandag', 'Tirsdag', 'Onsdag', 'Torsdag', 'Fredag', 'Lørdag'],
    loading: 'Laster...'
  },
  en: {
    days: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'],
    loading: 'Loading...'
  }
};

function dayNameOffset(locale) {
  switch (locale) {
    case 'nb':
      return 1;

    default:
      return 0;
  }
}

function dayNameShort(_ref) {
  var dayOfWeek = _ref.dayOfWeek,
      envLocale = _ref.envLocale,
      langLocale = _ref.langLocale;
  return i18n[langLocale].days[(dayOfWeek + dayNameOffset(envLocale)) % 7].slice(0, 2);
}

function Day(_ref2) {
  var day = _ref2.day,
      onDateClick = _ref2.onDateClick,
      selectedDate = _ref2.selectedDate;
  var isSelected = selectedDate === day.date;
  return (
    /*#__PURE__*/
    React.createElement("div", {
      onClick: function onClick() {
        if (day.status !== 'unavailable' && day.date) {
          onDateClick(day.date);
        }
      },
      className: "jsx-2177114953" + " " + "".concat(day.status || '').concat(isSelected ? ' selected' : '')
    }, day.date ?
    /*#__PURE__*/
    React.createElement("span", {
      className: "jsx-2177114953"
    }, parseInt(day.date.slice(-2), 10)) : null,
    /*#__PURE__*/
    React.createElement(_style["default"], {
      id: "2177114953"
    }, "div.jsx-2177114953{width:45px;height:45px;border:1px solid #ebe8e3;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-webkit-justify-content:center;-ms-flex-pack:center;justify-content:center;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;margin:-1px 0 0 -1px;}.available.jsx-2177114953,.unknown.jsx-2177114953{cursor:pointer;}.available.jsx-2177114953:hover,.unknown.jsx-2177114953:hover,.selected.jsx-2177114953{background-color:#019288;color:#fff;}.unavailable.jsx-2177114953{color:#ebe8e3;-webkit-text-decoration:line-through;text-decoration:line-through;}"))
  );
}

function Week(_ref3) {
  var days = _ref3.days,
      minDate = _ref3.minDate,
      onDateClick = _ref3.onDateClick,
      selectedDate = _ref3.selectedDate,
      isDateAvailable = _ref3.isDateAvailable;
  return (
    /*#__PURE__*/
    React.createElement(_Grid.Grid, {
      type: "xs"
    }, days.map(function (day) {
      var isWithinMinDate = minDate && day.date < minDate;
      var isAvailable = !isDateAvailable || isDateAvailable(day.date);
      var status = isAvailable && !isWithinMinDate ? day.status : 'unavailable';
      return (
        /*#__PURE__*/
        React.createElement(Day, {
          day: Object.assign({}, day, {
            status: status
          }),
          key: day.date,
          onDateClick: onDateClick,
          selectedDate: selectedDate
        })
      );
    }))
  );
}

function WeekDayLabels(_ref4) {
  var envLocale = _ref4.envLocale,
      langLocale = _ref4.langLocale;

  var i18nDay = function i18nDay(dayOfWeek) {
    return dayNameShort({
      dayOfWeek: dayOfWeek,
      envLocale: envLocale,
      langLocale: langLocale
    });
  };

  return (
    /*#__PURE__*/
    React.createElement(_Grid.Grid, {
      type: "xs"
    }, (0, _times["default"])(7, function (j) {
      return (
        /*#__PURE__*/
        React.createElement("div", {
          key: j,
          className: "jsx-2729199022"
        }, i18nDay(j))
      );
    }),
    /*#__PURE__*/
    React.createElement(_style["default"], {
      id: "2729199022"
    }, "div.jsx-2729199022{width:45px;height:45px;border:1px solid transparent;color:#929292;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-webkit-justify-content:center;-ms-flex-pack:center;justify-content:center;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;margin:-1px 0 0 -1px;text-transform:lowercase;}"))
  );
}

function Navigation(_ref5) {
  var children = _ref5.children,
      onPrevMonthClick = _ref5.onPrevMonthClick,
      onNextMonthClick = _ref5.onNextMonthClick;
  return (
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-2393274479" + " " + "main mbm"
    },
    /*#__PURE__*/
    React.createElement("button", {
      onClick: onPrevMonthClick,
      type: "button",
      className: "jsx-2393274479" + " " + "prev"
    },
    /*#__PURE__*/
    React.createElement("img", {
      alt: "",
      src: _LeftLineBlack["default"],
      className: "jsx-2393274479"
    })),
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-2393274479" + " " + "child"
    }, children),
    /*#__PURE__*/
    React.createElement("button", {
      onClick: onNextMonthClick,
      type: "button",
      className: "jsx-2393274479" + " " + "next"
    },
    /*#__PURE__*/
    React.createElement("img", {
      alt: "",
      src: _RightLineBlack["default"],
      className: "jsx-2393274479"
    })),
    /*#__PURE__*/
    React.createElement(_style["default"], {
      id: "2393274479"
    }, "img.jsx-2393274479{width:20px;}button.jsx-2393274479{background-color:transparent;border:1px solid #ebe8e3;width:45px;height:35px;border-radius:2px;font-size:1.9rem;cursor:pointer;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-webkit-justify-content:center;-ms-flex-pack:center;justify-content:center;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;}button.jsx-2393274479:hover{border-color:rgb(75,75,75);}.main.jsx-2393274479{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-webkit-justify-content:center;-ms-flex-pack:center;justify-content:center;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;font-size:2.1rem;}.prev.jsx-2393274479{margin-right:auto;}.next.jsx-2393274479{margin-left:auto;}.child.jsx-2393274479{margin:0 auto;}"))
  );
}

function Label(_ref6) {
  var children = _ref6.children;
  return (
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-279552580"
    },
    /*#__PURE__*/
    React.createElement("strong", {
      className: "jsx-279552580"
    }, children),
    /*#__PURE__*/
    React.createElement(_style["default"], {
      id: "279552580"
    }, "div.jsx-279552580{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-webkit-justify-content:center;-ms-flex-pack:center;justify-content:center;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;font-size:2.1rem;}"))
  );
}

function DatePicker(_ref7) {
  var envLocale = _ref7.envLocale,
      isLoading = _ref7.isLoading,
      label = _ref7.label,
      langLocale = _ref7.langLocale,
      minDate = _ref7.minDate,
      onClose = _ref7.onClose,
      onDateClick = _ref7.onDateClick,
      onNextMonthClick = _ref7.onNextMonthClick,
      onPrevMonthClick = _ref7.onPrevMonthClick,
      selectedDate = _ref7.selectedDate,
      weeks = _ref7.weeks,
      isDateAvailable = _ref7.isDateAvailable;
  var text = i18n[langLocale];
  return (
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-644667019"
    },
    /*#__PURE__*/
    React.createElement(_Backdrop.Backdrop, {
      onClick: onClose
    }),
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-644667019" + " " + "main"
    },
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-644667019" + " " + "inner"
    },
    /*#__PURE__*/
    React.createElement(Navigation, {
      onPrevMonthClick: onPrevMonthClick,
      onNextMonthClick: onNextMonthClick
    },
    /*#__PURE__*/
    React.createElement(Label, null, label)), weeks ?
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-644667019" + " " + "cal"
    }, isLoading ?
    /*#__PURE__*/
    React.createElement(_Updating.Updating, null) : null,
    /*#__PURE__*/
    React.createElement(WeekDayLabels, {
      envLocale: envLocale,
      langLocale: langLocale
    }), weeks.map(function (week) {
      return (
        /*#__PURE__*/
        React.createElement(Week, {
          days: week.days,
          key: week.days[0].date,
          minDate: minDate,
          onDateClick: onDateClick,
          selectedDate: selectedDate,
          isDateAvailable: isDateAvailable
        })
      );
    })) :
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-644667019"
    }, text.loading))),
    /*#__PURE__*/
    React.createElement(_style["default"], {
      id: "644667019"
    }, ".main.jsx-644667019{margin-top:-20px;margin-left:20px;position:absolute;z-index:100000;background-color:#fff;border:1px solid #ebe8e3;border-radius:3px;box-shadow:0 2px 6px rgba(0,0,0,0.05);}.inner.jsx-644667019{position:relative;top:1px;left:1px;width:308px;margin:20px;}.cal.jsx-644667019{position:relative;}"))
  );
}

DatePicker.defaultProps = {
  envLocale: 'nb',
  langLocale: 'en'
};