"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AvatarMenu = AvatarMenu;
exports.HeaderHostingMenu = HeaderHostingMenu;
exports.HeaderWebMenu = HeaderWebMenu;
exports.onLoginClick = onLoginClick;

var _style = _interopRequireDefault(require("styled-jsx/style"));

var React = _interopRequireWildcard(require("react"));

var _Avatar = require("./Avatar");

var _constants = require("./constants");

var _Header = require("./Header");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; if (obj != null) { var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var i18n = {
  nb: {
    account: 'Kontoinstillinger',
    accounts: 'Kontoer',
    admin: 'Admin',
    becomeHost: 'Bli en utleier',
    favorites: 'Favoritter',
    host: 'Utleier',
    inbox: 'Meldinger',
    performInvoicing: 'Fakturering',
    adminTransferVenues: 'Overfør lokaler',
    login: 'Logg inn',
    logout: 'Logg ut',
    menu: 'Meny',
    selectAccount: 'Velg konto',
    selectedAccount: 'Du administrerer:',
    stats: 'Statistikkpanel',
    users: 'Brukere',
    venues: 'Utleiesteder'
  },
  en: {
    account: 'Account settings',
    accounts: 'Accounts',
    admin: 'Admin',
    becomeHost: 'Become a host',
    favorites: 'Favorites',
    help: 'Help',
    host: 'Host',
    inbox: 'Messages',
    performInvoicing: 'Invoicing',
    adminTransferVenues: 'Transfer venues',
    login: 'Login',
    logout: 'Log out',
    menu: 'Menu',
    selectAccount: 'Choose account',
    selectedAccount: 'You manage:',
    stats: 'Stats dashboard',
    users: 'User profiles',
    venues: 'Venues'
  }
};
var URI = {
  accounts: '/hosting/accounts',
  adminPerformInvoicing: '/hosting/accounting/invoicing',
  adminTransferVenues: '/hosting/venue-transfer',
  adminStats: '/inbox/admin/stats',
  adminUsers: '/inbox/admin/users',
  becomeHost: {
    en: '/list-your-space',
    nb: '/leie-ut-lokale'
  },
  favorites: {
    en: '/favorites',
    nb: '/favoritter'
  },
  help: 'https://eventum.zendesk.com',
  hostVenues: '/hosting/venues',
  inbox: '/inbox/',
  login: '/inbox/login',
  logout: '/inbox/logout',
  yourProfile: '/your-profile'
};

function returnUrl() {
  var currentHref = window.location.href;
  return encodeURIComponent(currentHref.replace(window.location.origin, ''));
}

function onLoginClick(event) {
  event.preventDefault();
  window.location.href = "".concat(URI.login, "?returnUrl=").concat(returnUrl());
}

function AdminMenuLinks(_ref) {
  var locale = _ref.locale,
      onClick = _ref.onClick;
  var text = i18n[locale];
  return (
    /*#__PURE__*/
    React.createElement(React.Fragment, null,
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: URI.accounts,
      onClick: onClick
    }, text.accounts),
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: URI.adminUsers,
      onClick: onClick
    }, text.users),
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: URI.adminPerformInvoicing,
      onClick: onClick
    }, text.performInvoicing),
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: URI.adminTransferVenues,
      onClick: onClick
    }, text.adminTransferVenues),
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: URI.adminStats,
      onClick: onClick
    }, text.stats))
  );
}

function AdminMenu(_ref2) {
  var locale = _ref2.locale;
  var text = i18n[locale];
  return (
    /*#__PURE__*/
    React.createElement(_Header.HeaderButtonMenu, {
      buttonChild: text.admin
    },
    /*#__PURE__*/
    React.createElement(AdminMenuLinks, {
      locale: locale
    }))
  );
}

function HostMenu(_ref3) {
  var locale = _ref3.locale;
  var text = i18n[locale];
  return (
    /*#__PURE__*/
    React.createElement(_Header.HeaderButtonMenu, {
      buttonChild: text.host
    },
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: URI.accounts
    }, text.account),
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: URI.hostVenues
    }, text.venues))
  );
}

function UserMenuLinks(_ref4) {
  var locale = _ref4.locale,
      onClick = _ref4.onClick;
  var text = i18n[locale];
  return (
    /*#__PURE__*/
    React.createElement(React.Fragment, null,
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: URI.logout,
      onClick: onClick
    }, text.logout))
  );
}

function AvatarMenu(_ref5) {
  var avatarAlt = _ref5.avatarAlt,
      avatarSrc = _ref5.avatarSrc,
      locale = _ref5.locale;
  var avatar =
  /*#__PURE__*/
  React.createElement(_Avatar.Avatar, {
    altPart: avatarAlt,
    src: avatarSrc,
    width: 30
  });
  return (
    /*#__PURE__*/
    React.createElement(_Header.HeaderButtonMenu, {
      buttonChild: avatar
    },
    /*#__PURE__*/
    React.createElement(UserMenuLinks, {
      locale: locale
    }))
  );
}

function HostingMenuMobile(_ref6) {
  var accountName = _ref6.accountName,
      accountSlug = _ref6.accountSlug,
      inboxUntreatedCount = _ref6.inboxUntreatedCount,
      inboxUri = _ref6.inboxUri,
      isAdmin = _ref6.isAdmin,
      locale = _ref6.locale,
      onClick = _ref6.onClick;
  var text = i18n[locale];
  var untreatedColor = inboxUntreatedCount && inboxUntreatedCount > 0 ? _constants.COLORS.ERROR : 'green';
  return (
    /*#__PURE__*/
    React.createElement(React.Fragment, null, accountName && accountSlug ?
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: URI.accounts,
      onClick: onClick
    }, "".concat(text.selectedAccount, " ").concat(accountName)) : null,
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: inboxUri || URI.inbox,
      onClick: onClick
    },
    /*#__PURE__*/
    React.createElement("span", null, text.inbox), inboxUntreatedCount ?
    /*#__PURE__*/
    React.createElement("span", {
      style: {
        color: untreatedColor
      }
    }, " (", inboxUntreatedCount, ")") : null),
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: accountSlug ? "/manage-account/".concat(accountSlug, "/venues") : URI.hostVenues,
      onClick: onClick
    }, text.venues),
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: accountSlug ? "/manage-account/".concat(accountSlug) : URI.accounts,
      onClick: onClick
    }, text.account), isAdmin ?
    /*#__PURE__*/
    React.createElement(AdminMenuLinks, {
      locale: locale,
      onClick: onClick
    }) : null,
    /*#__PURE__*/
    React.createElement(UserMenuLinks, {
      locale: locale,
      onClick: onClick
    }))
  );
}

function HeaderHostingMenu(_ref7) {
  var accountName = _ref7.accountName,
      accountSlug = _ref7.accountSlug,
      hideAccountSelect = _ref7.hideAccountSelect,
      inboxUntreatedCount = _ref7.inboxUntreatedCount,
      inboxUri = _ref7.inboxUri,
      isAdmin = _ref7.isAdmin,
      locale = _ref7.locale;
  var text = i18n[locale];
  var untreatedColor = inboxUntreatedCount && inboxUntreatedCount > 0 ? _constants.COLORS.ERROR : 'green';
  return (
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-2651921251" + " " + "main"
    },
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-2651921251" + " " + "mobile"
    },
    /*#__PURE__*/
    React.createElement(_Header.HeaderButtonMenu, {
      buttonChild: text.menu,
      hasArrow: true
    },
    /*#__PURE__*/
    React.createElement(HostingMenuMobile, {
      accountName: accountName,
      accountSlug: accountSlug,
      inboxUntreatedCount: inboxUntreatedCount,
      inboxUri: inboxUri,
      isAdmin: isAdmin,
      locale: locale
    }))),
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-2651921251" + " " + "desktop"
    },
    /*#__PURE__*/
    React.createElement(_Header.HeaderLink, {
      href: inboxUri || URI.inbox
    },
    /*#__PURE__*/
    React.createElement("span", {
      className: "jsx-2651921251"
    }, text.inbox), inboxUntreatedCount ?
    /*#__PURE__*/
    React.createElement("span", {
      style: {
        color: untreatedColor
      },
      className: "jsx-2651921251"
    }, " (", inboxUntreatedCount, ")") : null),
    /*#__PURE__*/
    React.createElement(_Header.HeaderLink, {
      href: accountSlug ? "/manage-account/".concat(accountSlug, "/venues") : URI.hostVenues
    }, text.venues),
    /*#__PURE__*/
    React.createElement(_Header.HeaderLink, {
      href: accountSlug ? "/manage-account/".concat(accountSlug) : URI.accounts
    }, text.account), isAdmin ?
    /*#__PURE__*/
    React.createElement(AdminMenu, {
      locale: locale
    }) : null, accountSlug && accountName ?
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-2651921251" + " " + "account"
    },
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-2651921251"
    }, text.selectedAccount),
    /*#__PURE__*/
    React.createElement(_Header.HeaderLink, {
      href: URI.accounts
    }, accountName)) :
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-2651921251" + " " + "account"
    }, !hideAccountSelect ?
    /*#__PURE__*/
    React.createElement(_Header.HeaderLink, {
      href: URI.accounts
    }, text.selectAccount) : null)),
    /*#__PURE__*/
    React.createElement(_style["default"], {
      id: "2651921251"
    }, ".main.jsx-2651921251{-webkit-flex:1 auto;-ms-flex:1 auto;flex:1 auto;}.account.jsx-2651921251{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;margin-left:auto;}.desktop.jsx-2651921251{display:none;}@media only screen and (min-width:1024px){.desktop.jsx-2651921251{-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex:1 auto;-ms-flex:1 auto;flex:1 auto;}.mobile.jsx-2651921251{display:none;}}"))
  );
}

HeaderHostingMenu.defaultValue = {
  isAdmin: false
};

function WebMenuMobile(_ref8) {
  var isAdmin = _ref8.isAdmin,
      isHost = _ref8.isHost,
      isLoggedIn = _ref8.isLoggedIn,
      locale = _ref8.locale,
      onClick = _ref8.onClick;
  var text = i18n[locale];
  return (
    /*#__PURE__*/
    React.createElement(React.Fragment, null, isHost ? null :
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: URI.becomeHost[locale],
      onClick: onClick
    }, text.becomeHost),
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: URI.favorites[locale],
      onClick: onClick
    }, text.favorites), isLoggedIn ?
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: URI.inbox,
      onClick: onClick
    }, text.inbox) : null, !isLoggedIn ?
    /*#__PURE__*/
    React.createElement(_Header.ModalMenuLink, {
      href: URI.login,
      onClick: onLoginClick
    }, text.login) : null, isAdmin ?
    /*#__PURE__*/
    React.createElement(AdminMenuLinks, {
      locale: locale,
      onClick: onClick
    }) : null, isLoggedIn ?
    /*#__PURE__*/
    React.createElement(UserMenuLinks, {
      locale: locale,
      onClick: onClick
    }) : null)
  );
}

function HeaderWebMenu(_ref9) {
  var isAdmin = _ref9.isAdmin,
      isHost = _ref9.isHost,
      locale = _ref9.locale,
      isLoggedIn = _ref9.isLoggedIn;
  var text = i18n[locale];
  return (
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-1553694561"
    },
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-1553694561" + " " + "mobile"
    },
    /*#__PURE__*/
    React.createElement(_Header.HeaderButtonMenu, {
      buttonChild: text.menu,
      hasArrow: true
    },
    /*#__PURE__*/
    React.createElement(WebMenuMobile, {
      isAdmin: isAdmin,
      isHost: isHost,
      isLoggedIn: isLoggedIn,
      locale: locale
    }))),
    /*#__PURE__*/
    React.createElement("div", {
      className: "jsx-1553694561" + " " + "desktop"
    }, isHost ?
    /*#__PURE__*/
    React.createElement(HostMenu, {
      locale: locale
    }) :
    /*#__PURE__*/
    React.createElement(_Header.HeaderLink, {
      href: URI.becomeHost[locale]
    }, text.becomeHost),
    /*#__PURE__*/
    React.createElement(_Header.HeaderLink, {
      href: URI.favorites[locale]
    }, text.favorites), isLoggedIn ?
    /*#__PURE__*/
    React.createElement(_Header.HeaderLink, {
      href: URI.inbox
    }, text.inbox) : null, isAdmin ?
    /*#__PURE__*/
    React.createElement(AdminMenu, {
      locale: locale
    }) : null, !isLoggedIn ?
    /*#__PURE__*/
    React.createElement(_Header.HeaderLink, {
      href: URI.login,
      onClick: onLoginClick
    }, text.login) : null),
    /*#__PURE__*/
    React.createElement(_style["default"], {
      id: "1553694561"
    }, ".desktop.jsx-1553694561{display:none;}@media only screen and (min-width:768px){.desktop.jsx-1553694561{-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex:1 auto;-ms-flex:1 auto;flex:1 auto;}.mobile.jsx-1553694561{display:none;}}"))
  );
}